local AMissileSerpentineProjectile = import('/lua/aeonprojectiles.lua').AeonHeavyMissile
local RandF = import('/lua/utilities.lua').GetRandomFloat
local EffectTemplate = import('/lua/EffectTemplates.lua')

AeonHeavyMissile = Class(AMissileSerpentineProjectile) {
    OnCreate = function(self)
        AMissileSerpentineProjectile.OnCreate(self)
        self:SetCollisionShape('Sphere', 0, 0, 0, 2.0)
        self.MovementTurnLevel = 1
        self:ForkThread( self.MovementThread )
        
    end,
    
    OnImpact = function(self, impactType, targetEntity)
	self:ForkThread( self.SplitThread )
    end,

    MovementThread = function(self)
        local army = self:GetArmy()
        local x,y,z = self:GetVelocity()
        y = 5
        self:SetVelocity(x, y, z)        
        self:TrackTarget(false)
        self:SetCollision(true)
        #WaitSeconds(2)
        self:SetTurnRate(5)
        WaitSeconds(0.5)
        self:TrackTarget(true)
        self:SetTurnRate(10)
        WaitSeconds(0.5)
        while not self:BeenDestroyed() do
            self:SetTurnRateByDist()
            WaitSeconds(0.5)
        end
    end,
    
    SplitThread = function(self)
		
        ###Create/play the split effects.
		for k,v in EffectTemplate.AMercyGuidedMissileSplit do
            CreateEmitterOnEntity(self,self:GetArmy(),v)
        end
        
        
		WaitSeconds( 0.1 )
		# Create several other projectiles in a dispersal pattern
        local vx, vy, vz = self:GetVelocity()
        local velocity = 16		
        local numProjectiles = 8
        local angle = (2*math.pi) / numProjectiles
        local angleInitial = RandF( 0, angle )
        local ChildProjectileBP = '/mods/Reds Unit Pack/projectiles/AeonHeavyMissile02/AeonHeavyMissile02_proj.bp'          
        local spreadMul = 0.4 # Adjusts the width of the dispersal        
       
        local xVec = 0 
        local yVec = vy*0.8
        local zVec = 0
        
        # Adjust damage by number of split projectiles
        self.DamageData.DamageAmount = self.DamageData.DamageAmount / numProjectiles

        # Launch projectiles at semi-random angles away from split location
        for i = 0, (numProjectiles -1) do
            xVec = vx + math.sin(angleInitial + (i*angle) ) * spreadMul * RandF( 0.6, 1.3 )
            zVec = vz + math.cos(angleInitial + (i*angle) ) * spreadMul * RandF( 0.6, 1.3 )
            local proj = self:CreateChildProjectile(ChildProjectileBP)
            proj:SetVelocity( xVec, yVec, zVec )
            proj:SetVelocity( velocity * RandF( 0.8, 1.2 ) )
            proj:PassDamageData(self.DamageData)                        
        end        
        self:Destroy()    
    end,
    
    SetTurnRateByDist = function(self)
        local dist = self:GetDistanceToTarget()
        if dist > 125 and self.MovementTurnLevel < 2 then
            self:SetTurnRate(30)
            self.MovementTurnLevel = 1
        elseif dist > 85 and dist <= 125 and self.MovementTurnLevel < 3 then
            self:SetTurnRate(40)
            self.MovementTurnLevel = 2
        elseif dist > 40 and dist <= 85 and self.MovementTurnLevel < 4 then
            self:SetTurnRate(50)
            self.MovementTurnLevel = 3
        elseif dist < 40 then
            self:SetTurnRate(85)
            self.MovementTurnLevel = 4
        end
    end,

    GetDistanceToTarget = function(self)
        local tpos = self:GetCurrentTargetPosition()
        local mpos = self:GetPosition()
        local dist = VDist2(mpos[1], mpos[3], tpos[1], tpos[3])
        return dist
    end,
    
}

TypeClass = AeonHeavyMissile